Natural Language Processing with Python - O'Reilly Media
Author: Steven Bird, Ewan Klein, Edward Loper
Description: This book offers a highly accessible introduction to Natural Language Processing, the field that underpins a variety of language technologies ranging from predictive text and email filtering to automatic summarization and translation. You'll learn ho...
Keywords: Natural Language Processing with Python, Python, Natural Language Toolkit, Natural Language Processing, Semantics, 0-596-51649-5, 0596516495, 9780596516499, 978-0-596-51649-9, Steven Bird, Ewan Klein, Edward Loper,oreilly, O'Reilly, o'reilly
Date: Jun. 12, 2009

- Skip navigation
- Skip to search form

# O'Reilly Books & Videos

Spreading the Knowledge of Technology Innovators
Buying Options
Natural Language Processing with Python
Print $44.99
Print+Ebook $49.49
Ebook $35.99
(Mobi, PDF, ePub)
Safari Books Online
What is this?
Print £34.50
What is this?

# Natural Language Processing with Python

## Analyzing Text with the Natural Language Toolkit

By
  Steven Bird, Ewan Klein, Edward Loper
Publisher:
  O'Reilly Media
Released:
  June 2009
Pages:
  512

Press Release

- Buy 2 Get 1 Free
- Free Shipping
- 100% Satisfaction Guarantee

See larger cover

- Register Your Book
- View/Submit Errata
- Media Praise

Do you have a question about O'Reilly's products and services? Share an idea! Report a problem...
Service and support by Satisfaction